#ifndef __KINGATE_EXCEPTION_H
#define __KINGATE_EXCEPTION_H

#include <stdexcept>
#include <konforka/exception.h>

/**
 * @file
 * @brief The kingate-specific exceptions.
 */

/**
 * @brief the main kingate namespace.
 */
namespace kingate {
    using namespace std;

    /**
     * The base for kingate-specific exception.
     */
    class exception : public konforka::exception {
	public:
	    explicit exception(const string& w)
		: konforka::exception(NOCODEPOINT,w) { }
	    exception(const string& fi,const string& fu,int l,const string &w)
		: konforka::exception(fi,fu,l,w) { }
    };

    /**
     * Thrown if the specified variable or parameter wasn't found.
     */
    class exception_notfound : public exception {
	public:
	    explicit exception_notfound(const string& w)
		: exception(w) { }
	    exception_notfound(const string& fi,const string& fu,int l,const string& w)
		: exception(fi,fu,l,w) { }
    };

    /**
     * Thrown in case of unexpected server behaviour.
     */
    class server_error : public exception {
	public:
	    server_error(const string& fi,const string& fu,int l,const string& w)
		: exception(fi,fu,l,w) { }
    };
}

#endif /* __KINGATE_EXCEPTION_H */
/*
 * vim:set ft=cpp:
 */
